@@ -328,7 +328,8 @@ clustCoDa <- function(x, k=NULL, method="Mclust",
                      row.names = paste(method, "-", distMethod, sep=""))
   }
   if( length(bic) > 0 ){
-    cl <- Mclust(x,k,k)
+    browser()
+    cl <- Mclust(x, G = k)
     bics <- vector()
     for(i in 1:k ){
       bics[i] <- min(mclustBIC(x[cl$class==i,], 1), na.rm=TRUE)
@@ -365,6 +366,7 @@ clustCoDa <- function(x, k=NULL, method="Mclust",
     clust$centerSimplex <- pivotCoordInv(clust$center)
     gmsc <- apply(clust$centerSimplex, 2, gm)
     di <- gms/gmsc
+    # di <- gms/clust$centerSimplex
     for(i in 1:ncol(clust$centerSimplex)){
       clust$centerSimplex[, i] <- clust$centerSimplex[, i] * di[i]
     }
