@@ -25,7 +25,7 @@
 #' ternaryDiag(x, grid=FALSE, line="ellipse")
 #' 
 ternaryDiagEllipse <- function(x, tolerance=c(0.9,0.95,0.975), locscatt="MCD", ...){
-	z <- isomLR(x)
+	z <- pivotCoord(x)
 	if(locscatt=="MCD"){
 		cv <- robustbase::covMcd(z)
 		mu <- cv$center
@@ -36,7 +36,7 @@ ternaryDiagEllipse <- function(x, tolerance=c(0.9,0.95,0.975), locscatt="MCD", .
 	}
 	dat1 <- drawMahal(z, mu, cm, plot=FALSE, whichlines=tolerance) 
 	for(i in 1:length(tolerance)){
-		e <- isomLRinv(cbind(dat1$mdX[,i], dat1$mdY[,i]))
+		e <- pivotCoordInv(cbind(dat1$mdX[,i], dat1$mdY[,i]))
 		xp1 <- e[, 2] + e[, 3]/2
 		yp1 <- e[, 3] * sqrt(3)/2	  
 		lines(xp1, yp1, xlim = c(0, 1), ylim = c(0, 0.9), #frame.plot = FALSE, 
